@@ -218,231 +218,231 @@ LIKELY_SUBTAGS = {
 
 
 ENGLISH_SCRIPT_NAMES = {
-    "Cans": u"Canadian Aboriginal",  # shorten name for display purposes,
+    "Cans": "Canadian Aboriginal",  # shorten name for display purposes,
     # match Noto font name
 }
 
 ENGLISH_LANGUAGE_NAMES = {
-    "abr": u"Abron",
-    "abq": u"Abaza",
-    "aho": u"Ahom",
-    "aii": u"Assyrian Neo-Aramaic",
-    "akz": u"Alabama",
-    "amo": u"Amo",
-    "aoz": u"Uab Meto",
-    "atj": u"Atikamekw",
-    "bap": u"Bantawa",
-    "bci": u"Baoulé",
-    "ber": u"Berber",
-    "bft": u"Balti",
-    "bfy": u"Bagheli",
-    "bgc": u"Haryanvi",
-    "bgx": u"Balkan Gagauz Turkish",
-    "bh": u"Bihari",
-    "bhb": u"Bhili",
-    "bhi": u"Bhilali",
-    "bhk": u"Albay Bikol",
-    "bjj": u"Kanauji",
-    "bku": u"Buhid",
-    "blt": u"Tai Dam",
-    "bmq": u"Bomu",
-    "bqi": u"Bakhtiari",
-    "bqv": u"Koro Wachi",
-    "bsq": u"Bassa",
-    "bto": u"Rinconada Bikol",
-    "btv": u"Bateri",
-    "buc": u"Bushi",
-    "bvb": u"Bube",
-    "bya": u"Batak",
-    "bze": u"Jenaama Bozo",
-    "bzx": u"Kelengaxo Bozo",
-    "ccp": u"Chakma",
-    "cja": u"Western Cham",
-    "cjs": u"Shor",
-    "cjm": u"Eastern Cham",
-    "ckt": u"Chukchi",
-    "cpf": u"French-based Creoles",
-    "crj": u"Southern East Cree",
-    "crk": u"Plains Cree",
-    "crl": u"Northern East Cree",
-    "crm": u"Moose Cree",
-    "crs": u"Seselwa Creole French",
-    "csw": u"Swampy Cree",
-    "ctd": u"Tedim Chin",
-    "dcc": u"Deccan",
-    "dng": u"Dungan",
-    "dnj": u"Dan",
-    "dtm": u"Tomo Kan Dogon",
-    "eky": u"Eastern Kayah",
-    "ett": u"Etruscan",
-    "evn": u"Evenki",
-    "ffm": u"Maasina Fulfulde",
-    "fud": u"East Futuna",
-    "fuq": u"Central-Eastern Niger Fulfulde",
-    "fuv": u"Nigerian Fulfulde",
-    "gbm": u"Garhwali",
-    "gcr": u"Guianese Creole French",
-    "ggn": u"Eastern Gurung",
-    "gjk": u"Kachi Koli",
-    "gju": u"Gujari",
-    "gld": u"Nanai",
-    "gos": u"Gronings",
-    "grt": u"Garo",
-    "gub": u"Guajajára",
-    "gvr": u"Western Gurung",
-    "haz": u"Hazaragi",
-    "hlu": u"Hieroglyphic Luwian",
-    "hmd": u"A-Hmao",
-    "hnd": u"Southern Hindko",
-    "hne": u"Chhattisgarhi",
-    "hnj": u"Hmong Njua",
-    "hnn": u"Hanunoo",
-    "hno": u"Northern Hindko",
-    "hoc": u"Ho",
-    "hoj": u"Haroti",
-    "hop": u"Hopi",
-    "ikt": u"Inuinnaqtun",
-    "jml": u"Jumli",
-    "kao": u"Xaasongaxango",
-    "kca": u"Khanty",
-    "kck": u"Kalanga",
-    "kdt": u"Kuy",
-    "kfr": u"Kachchi",
-    "kfy": u"Kumaoni",
-    "kge": u"Komering",
-    "khb": u"Lü",
-    "khn": u"Khandesi",
-    "kht": u"Khamti",
-    "kjg": u"Khmu",
-    "kjh": u"Khakas",
-    "kkh": u"Khün",
-    "kpy": u"Koryak",
-    "kvr": u"Kerinci",
-    "kvx": u"Parkari Koli",
-    "kxm": u"Northern Khmer",
-    "kxp": u"Wadiyara Koli",
-    "kyu": u"Western Kayah",
-    "lab": u"Linear A",
-    "laj": u"Lango",
-    "lbe": u"Lak",
-    "lbw": u"Tolaki",
-    "lcp": u"Western Lawa",
-    "lep": u"Lepcha",
-    "lif": u"Limbu",
-    "lis": u"Lisu",
-    "ljp": u"Lampung Api",
-    "lki": u"Laki",
-    "lmn": u"Lambadi",
-    "lrc": u"Northern Luri",
-    "lut": u"Lushootseed",
-    "luz": u"Southern Luri",
-    "lwl": u"Eastern Lawa",
-    "maz": u"Central Mazahua",
-    "mdh": u"Maguindanaon",
-    "mdt": u"Mbere",
-    "mfa": u"Pattani Malay",
-    "mgp": u"Eastern Magar",
-    "mgy": u"Mbunga",
-    "mns": u"Mansi",
-    "mnw": u"Mon",
-    "moe": u"Montagnais",
-    "mrd": u"Western Magar",
-    "mro": u"Mru",
-    "mru": u"Cameroon Mono",
-    "mtr": u"Mewari",
-    "mvy": u"Indus Kohistani",
-    "mwk": u"Kita Maninkakan",
-    "mxc": u"Manyika",
-    "myx": u"Masaaba",
-    "myz": u"Classical Mandaic",
-    "nch": u"Central Huasteca Nahuatl",
-    "ndc": u"Ndau",
-    "ngl": u"Lomwe",
-    "nhe": u"Eastern Huasteca Nahuatl",
-    "nhw": u"Western Huasteca Nahuatl",
-    "nij": u"Ngaju",
-    "nod": u"Northern Thai",
-    "noe": u"Nimadi",
-    "nsk": u"Naskapi",
-    "nxq": u"Naxi",
-    "ohu": u"Old Hungarian",
-    "osc": u"Oscan",
-    "otk": u"Old Turkish",
-    "pcm": u"Nigerian Pidgin",
-    "pka": u"Ardhamāgadhī Prākrit",
-    "pko": u"Pökoot",
-    "pra": u"Prakrit",  # language family name
-    "prd": u"Parsi-Dari",
-    "prs": u"Dari",
-    "puu": u"Punu",
-    "rcf": u"Réunion Creole French",
-    "rej": u"Rejang",
-    "ria": u"Riang",  # (India)
-    "rjs": u"Rajbanshi",
-    "rkt": u"Rangpuri",
-    "rmf": u"Kalo Finnish Romani",
-    "rmo": u"Sinte Romani",
-    "rmt": u"Domari",
-    "rmu": u"Tavringer Romani",
-    "rng": u"Ronga",
-    "rob": u"Tae’",
-    "ryu": u"Central Okinawan",
-    "saf": u"Safaliba",
-    "sck": u"Sadri",
-    "scs": u"North Slavey",
-    "sdh": u"Southern Kurdish",
-    "sef": u"Cebaara Senoufo",
-    "skr": u"Seraiki",
-    "smp": u"Samaritan",
-    "sou": u"Southern Thai",
-    "srb": u"Sora",
-    "srx": u"Sirmauri",
-    "swv": u"Shekhawati",
-    "sxn": u"Sangir",
-    "syi": u"Seki",
-    "syl": u"Sylheti",
-    "tab": u"Tabassaran",
-    "taj": u"Eastern Tamang",
-    "tbw": u"Tagbanwa",
-    "tdd": u"Tai Nüa",
-    "tdg": u"Western Tamang",
-    "tdh": u"Thulung",
-    "thl": u"Dangaura Tharu",
-    "thq": u"Kochila Tharu",
-    "thr": u"Rana Tharu",
-    "tkt": u"Kathoriya Tharu",
-    "tli": u"Tlingit",
-    "tsf": u"Southwestern Tamang",
-    "tsg": u"Tausug",
-    "tsj": u"Tshangla",
-    "ttj": u"Tooro",
-    "tts": u"Northeastern Thai",
-    "ude": u"Udihe",
-    "uli": u"Ulithian",
-    "unr": u"Mundari",
-    "unx": u"Munda",
-    "vic": u"Virgin Islands Creole English",
-    "vmw": u"Makhu",
-    "wbr": u"Wagdi",
-    "wbq": u"Waddar",
-    "wls": u"Wallisian",
-    "wtm": u"Mewati",
-    "xav": u"Xavánte",
-    "xcr": u"Carian",
-    "xlc": u"Lycian",
-    "xld": u"Lydian",
-    "xmn": u"Manichaean Middle Persian",
-    "xmr": u"Meroitic",
-    "xna": u"Ancient North Arabian",
-    "xnr": u"Kangri",
-    "xpr": u"Parthian",
-    "xsa": u"Sabaean",
-    "xsr": u"Sherpa",
-    "xum": u"Umbrian",
-    "yrk": u"Nenets",
-    "yua": u"Yucatec Maya",
-    "zdj": u"Ngazidja Comorian",
-    "zmi": u"Negeri Sembilan Malay",
+    "abr": "Abron",
+    "abq": "Abaza",
+    "aho": "Ahom",
+    "aii": "Assyrian Neo-Aramaic",
+    "akz": "Alabama",
+    "amo": "Amo",
+    "aoz": "Uab Meto",
+    "atj": "Atikamekw",
+    "bap": "Bantawa",
+    "bci": "Baoulé",
+    "ber": "Berber",
+    "bft": "Balti",
+    "bfy": "Bagheli",
+    "bgc": "Haryanvi",
+    "bgx": "Balkan Gagauz Turkish",
+    "bh": "Bihari",
+    "bhb": "Bhili",
+    "bhi": "Bhilali",
+    "bhk": "Albay Bikol",
+    "bjj": "Kanauji",
+    "bku": "Buhid",
+    "blt": "Tai Dam",
+    "bmq": "Bomu",
+    "bqi": "Bakhtiari",
+    "bqv": "Koro Wachi",
+    "bsq": "Bassa",
+    "bto": "Rinconada Bikol",
+    "btv": "Bateri",
+    "buc": "Bushi",
+    "bvb": "Bube",
+    "bya": "Batak",
+    "bze": "Jenaama Bozo",
+    "bzx": "Kelengaxo Bozo",
+    "ccp": "Chakma",
+    "cja": "Western Cham",
+    "cjs": "Shor",
+    "cjm": "Eastern Cham",
+    "ckt": "Chukchi",
+    "cpf": "French-based Creoles",
+    "crj": "Southern East Cree",
+    "crk": "Plains Cree",
+    "crl": "Northern East Cree",
+    "crm": "Moose Cree",
+    "crs": "Seselwa Creole French",
+    "csw": "Swampy Cree",
+    "ctd": "Tedim Chin",
+    "dcc": "Deccan",
+    "dng": "Dungan",
+    "dnj": "Dan",
+    "dtm": "Tomo Kan Dogon",
+    "eky": "Eastern Kayah",
+    "ett": "Etruscan",
+    "evn": "Evenki",
+    "ffm": "Maasina Fulfulde",
+    "fud": "East Futuna",
+    "fuq": "Central-Eastern Niger Fulfulde",
+    "fuv": "Nigerian Fulfulde",
+    "gbm": "Garhwali",
+    "gcr": "Guianese Creole French",
+    "ggn": "Eastern Gurung",
+    "gjk": "Kachi Koli",
+    "gju": "Gujari",
+    "gld": "Nanai",
+    "gos": "Gronings",
+    "grt": "Garo",
+    "gub": "Guajajára",
+    "gvr": "Western Gurung",
+    "haz": "Hazaragi",
+    "hlu": "Hieroglyphic Luwian",
+    "hmd": "A-Hmao",
+    "hnd": "Southern Hindko",
+    "hne": "Chhattisgarhi",
+    "hnj": "Hmong Njua",
+    "hnn": "Hanunoo",
+    "hno": "Northern Hindko",
+    "hoc": "Ho",
+    "hoj": "Haroti",
+    "hop": "Hopi",
+    "ikt": "Inuinnaqtun",
+    "jml": "Jumli",
+    "kao": "Xaasongaxango",
+    "kca": "Khanty",
+    "kck": "Kalanga",
+    "kdt": "Kuy",
+    "kfr": "Kachchi",
+    "kfy": "Kumaoni",
+    "kge": "Komering",
+    "khb": "Lü",
+    "khn": "Khandesi",
+    "kht": "Khamti",
+    "kjg": "Khmu",
+    "kjh": "Khakas",
+    "kkh": "Khün",
+    "kpy": "Koryak",
+    "kvr": "Kerinci",
+    "kvx": "Parkari Koli",
+    "kxm": "Northern Khmer",
+    "kxp": "Wadiyara Koli",
+    "kyu": "Western Kayah",
+    "lab": "Linear A",
+    "laj": "Lango",
+    "lbe": "Lak",
+    "lbw": "Tolaki",
+    "lcp": "Western Lawa",
+    "lep": "Lepcha",
+    "lif": "Limbu",
+    "lis": "Lisu",
+    "ljp": "Lampung Api",
+    "lki": "Laki",
+    "lmn": "Lambadi",
+    "lrc": "Northern Luri",
+    "lut": "Lushootseed",
+    "luz": "Southern Luri",
+    "lwl": "Eastern Lawa",
+    "maz": "Central Mazahua",
+    "mdh": "Maguindanaon",
+    "mdt": "Mbere",
+    "mfa": "Pattani Malay",
+    "mgp": "Eastern Magar",
+    "mgy": "Mbunga",
+    "mns": "Mansi",
+    "mnw": "Mon",
+    "moe": "Montagnais",
+    "mrd": "Western Magar",
+    "mro": "Mru",
+    "mru": "Cameroon Mono",
+    "mtr": "Mewari",
+    "mvy": "Indus Kohistani",
+    "mwk": "Kita Maninkakan",
+    "mxc": "Manyika",
+    "myx": "Masaaba",
+    "myz": "Classical Mandaic",
+    "nch": "Central Huasteca Nahuatl",
+    "ndc": "Ndau",
+    "ngl": "Lomwe",
+    "nhe": "Eastern Huasteca Nahuatl",
+    "nhw": "Western Huasteca Nahuatl",
+    "nij": "Ngaju",
+    "nod": "Northern Thai",
+    "noe": "Nimadi",
+    "nsk": "Naskapi",
+    "nxq": "Naxi",
+    "ohu": "Old Hungarian",
+    "osc": "Oscan",
+    "otk": "Old Turkish",
+    "pcm": "Nigerian Pidgin",
+    "pka": "Ardhamāgadhī Prākrit",
+    "pko": "Pökoot",
+    "pra": "Prakrit",  # language family name
+    "prd": "Parsi-Dari",
+    "prs": "Dari",
+    "puu": "Punu",
+    "rcf": "Réunion Creole French",
+    "rej": "Rejang",
+    "ria": "Riang",  # (India)
+    "rjs": "Rajbanshi",
+    "rkt": "Rangpuri",
+    "rmf": "Kalo Finnish Romani",
+    "rmo": "Sinte Romani",
+    "rmt": "Domari",
+    "rmu": "Tavringer Romani",
+    "rng": "Ronga",
+    "rob": "Tae’",
+    "ryu": "Central Okinawan",
+    "saf": "Safaliba",
+    "sck": "Sadri",
+    "scs": "North Slavey",
+    "sdh": "Southern Kurdish",
+    "sef": "Cebaara Senoufo",
+    "skr": "Seraiki",
+    "smp": "Samaritan",
+    "sou": "Southern Thai",
+    "srb": "Sora",
+    "srx": "Sirmauri",
+    "swv": "Shekhawati",
+    "sxn": "Sangir",
+    "syi": "Seki",
+    "syl": "Sylheti",
+    "tab": "Tabassaran",
+    "taj": "Eastern Tamang",
+    "tbw": "Tagbanwa",
+    "tdd": "Tai Nüa",
+    "tdg": "Western Tamang",
+    "tdh": "Thulung",
+    "thl": "Dangaura Tharu",
+    "thq": "Kochila Tharu",
+    "thr": "Rana Tharu",
+    "tkt": "Kathoriya Tharu",
+    "tli": "Tlingit",
+    "tsf": "Southwestern Tamang",
+    "tsg": "Tausug",
+    "tsj": "Tshangla",
+    "ttj": "Tooro",
+    "tts": "Northeastern Thai",
+    "ude": "Udihe",
+    "uli": "Ulithian",
+    "unr": "Mundari",
+    "unx": "Munda",
+    "vic": "Virgin Islands Creole English",
+    "vmw": "Makhu",
+    "wbr": "Wagdi",
+    "wbq": "Waddar",
+    "wls": "Wallisian",
+    "wtm": "Mewati",
+    "xav": "Xavánte",
+    "xcr": "Carian",
+    "xlc": "Lycian",
+    "xld": "Lydian",
+    "xmn": "Manichaean Middle Persian",
+    "xmr": "Meroitic",
+    "xna": "Ancient North Arabian",
+    "xnr": "Kangri",
+    "xpr": "Parthian",
+    "xsa": "Sabaean",
+    "xsr": "Sherpa",
+    "xum": "Umbrian",
+    "yrk": "Nenets",
+    "yua": "Yucatec Maya",
+    "zdj": "Ngazidja Comorian",
+    "zmi": "Negeri Sembilan Malay",
 }
 
 # Supplement mapping of languages to scripts
@@ -470,7 +470,7 @@ PARENT_LOCALES = {
 }
 
 NATIVE_NAMES = {
-    "mn-Mong": u"ᠮᠣᠨᠭᠭᠣᠯ ᠬᠡᠯᠡ",
+    "mn-Mong": "ᠮᠣᠨᠭᠭᠣᠯ ᠬᠡᠯᠡ",
 }
 
 EXEMPLARS = {
