@@ -52,39 +52,107 @@ def has_gsub_table(fontfile):
 
 
 SCRIPT_TO_OPENTYPE_SCRIPT_TAG = {
+    # Retrieved from Opentype 1.9 delta specs. Prerelease scripttags used out of necessity. https://docs.microsoft.com/en-us/typography/opentype/spec/scripttags
+    "Carian": "cari",
     "CypriotSyllabary": "cprt",
+    "CyproMinoan": "cpmn",
     "Deseret": "dsrt",
     "Glagolitic": "glag",
-    "Lisu": "lisu",
-    "Ogham": "ogam",
-    "OldItalic": "ital",
-    "Runic": "runr",
-    "Shavian": "shaw",
-    "Vai": "vai ",
-    "Carian": "cari",
     "EgyptianHieroglyphs": "egyp",
     "ImperialAramaic": "armi",
+    "LinearA": "lina",
     "LinearB": "linb",
+    "Lisu": "lisu",
     "Lycian": "lyci",
     "Lydian": "lydi",
+    "Ogham": "ogam",
+    "OldItalic": "ital",
     "OldPersian": "xpeo",
     "OldSouthArabian": "sarb",
     "OldTurkic": "orkh",
+    "OldSogdian": "sogo",
+    "OldNorthArabian": "narb",
+    "OldHungarian": "hung",
     "Osmanya": "osma",
     "Phoenician": "phnx",
     "SumeroAkkadianCuneiform": "xsux",
     "Ugaritic": "ugar",
     "OlChiki": "olck",
     "TaiLe": "tale",
-    # Following keys are added to satisfy the use case in merge_fonts.py
-    # Reference:
-    # https://www.google.com/get/noto/#sans-xsux
-    # https://www.google.com/get/noto/#sans-cprt
-    # https://www.google.com/get/noto/#sans-yiii
-    # https://www.microsoft.com/typography/otspec/scripttags.htm
     "Cuneiform": "xsux",
     "Cypriot": "cprt",
+    "Runic": "runr",
+    "Shavian": "shaw",
+    "Vai": "vai ",
     "Yi": "yi  ",
+    "AnatolianHieroglyphs": "hluw",
+    "Bamum": "bamu",
+    "ByzantineMusic": "byzm",
+    "Gothic": "goth",
+    "ImperialAramaic": "armi",
+    "InscriptionalPahlavi": "phli",
+    "InscriptionalParthian": "prti",
+    "Khojki": "khoj",
+    "MathematicalAlphanumericSymbols": "math",
+    "MeroiticCursive": "merc",
+    "MeroiticHieroglyphs": "mero",
+    "MusicalSymbols": "musc",
+    "Palmyrene": "palm",
+    "Rejang": "rjng",
+    "Samaritan": "samr",
+    "Carian": "cari",
+    "Ahom": "ahom",
+    "Adlam": "adlm",
+    "Dogra": "dogr",
+    "Lisu": "lisu",
+    "Mandaean": "mand",
+    "Manichaean": "mani",
+    "Tifinagh": "tfng",
+    "Wancho": "wcho",
+    "Yezidi": "yezi",
+    "Cherokee": "cher",
+    "Chorasmian": "chrs",
+    "PahawhHmong": "hmng",
+    "Phagspa": "phag",
+    "Sundanese": "sund",
+    "WarangCiti": "wara",
+    "SylotiNagri": "sylo",
+    "PsalterPahlavi": "phlp",
+    "CaucasianAlbanian": "aghb",
+    "Medefaidrin": "medf",
+    "MeiteiMayek": "mtei",
+    "MendeKikakui": "mend",
+    "Mro": "mroo",
+    "Multani": "mult",
+    "Nabataean": "nbat",
+    "Nandinagari": "nand",
+    "Newa": "newa",
+    "NewTaiLue": "talu",
+    "Nushu": "nshu",
+    "NyiakengPuachueHmong": "hmnp",
+    "OldPermic": "perm",
+    "SoraSompeng": "sora",
+    "Soyombo": "soyo",
+    "SylotiNagri": "sylo",
+    "Tagbanwa": "tagb",
+    "Tagalog": "tglg",
+    "Takri": "takr",
+    "TaiTham": "lana",
+    "TaiViet": "tavt",
+    "Tangut": "tang",
+    "Thaana": "thaa",
+    "UgariticCuneiform": "ugar",
+    "ZanabazarSquare": "zanb",
+    "SignWriting": "sgnw",
+    "OldUyghur": "ougr",
+    "Tangsa": "tnsa",
+    "Toto": "toto",
+    "Vithkuqi": "vith",
+    "Duployan": "dupl",
+    "Hatran": "hatr",
+    # These last two would only merge using the long script name including the 'NotoSerif' part
+    "NotoSerifYezidi": "yezi",
+    "NotoSerifNyiakengPuachueHmong": "hmnp",
 }
 
 
