@@ -1,4 +1,3 @@
-
 try:
     unicode = unicode
 except NameError:
@@ -9,3 +8,7 @@ try:
 except NameError:
     unichr = chr
 
+try:
+    basestring = basestring
+except NameError:
+    basestring = str
