@@ -299,7 +299,7 @@ class TestDigitWidths(FontTest):
     def test_superscript_digits(self):
         """Tests that 'numr' features maps digits to Unicode superscripts."""
         ascii_digits = "0123456789"
-        superscript_digits = u"⁰¹²³⁴⁵⁶⁷⁸⁹"
+        superscript_digits = "⁰¹²³⁴⁵⁶⁷⁸⁹"
         for font_file in self.font_files:
             numr_glyphs = layout.get_advances(
                 ascii_digits, font_file, "--features=numr"
@@ -462,7 +462,7 @@ class TestFeatures(FontTest):
                 [],
                 (
                     "%s feature is not applied correctly to '%s'"
-                    % (feature, u"".join(chars_with_no_sub).encode("UTF-8"))
+                    % (feature, "".join(chars_with_no_sub).encode("UTF-8"))
                 ),
             )
 
@@ -751,11 +751,11 @@ class TestSpacingMarks(FontTest):
         for font in self.font_files:
             print("Testing %s for spacing marks in combination..." % font)
             for base_letter in (
-                u"A\u00C6BCDEFGHIJKLMNO\u00D8\u01A0PRST"
-                u"U\u01AFVWXYZ"
-                u"a\u00E6bcdefghi\u0131j\u0237klmn"
-                u"o\u00F8\u01A1prs\u017Ftu\u01B0vwxyz"
-                u"\u03D2"
+                "A\u00C6BCDEFGHIJKLMNO\u00D8\u01A0PRST"
+                "U\u01AFVWXYZ"
+                "a\u00E6bcdefghi\u0131j\u0237klmn"
+                "o\u00F8\u01A1prs\u017Ftu\u01B0vwxyz"
+                "\u03D2"
             ):
                 print("Testing %s combinations" % base_letter)
                 for mark in self.marks_to_test:
@@ -793,9 +793,9 @@ class TestSoftDottedChars(FontTest):
             # TODO: replace the following list with actual derivation based on
             # Unicode's soft-dotted property
             for base_letter in (
-                u"ij\u012F\u0249\u0268\u029D\u02B2\u03F3\u0456"
-                u"\u0458\u1D62\u1D96\u1DA4\u1DA8\u1E2D\u1ECB"
-                u"\u2071\u2C7C"
+                "ij\u012F\u0249\u0268\u029D\u02B2\u03F3\u0456"
+                "\u0458\u1D62\u1D96\u1DA4\u1DA8\u1E2D\u1ECB"
+                "\u2071\u2C7C"
             ):
                 print("Testing %s combinations" % base_letter.encode("UTF-8"))
                 for mark in self.marks_to_test:
