@@ -16,7 +16,7 @@
 
 """Tests for coverage.py."""
 
-__author__ = 'roozbeh@google.com (Roozbeh Pournader)'
+__author__ = "roozbeh@google.com (Roozbeh Pournader)"
 
 import os
 from os import path
@@ -29,17 +29,18 @@ from hb_input_test import make_font
 
 class CharacterSetTest(unittest.TestCase):
     """Test class for coverage.character_set."""
+
     def test_sanity(self):
         """Test basic sanity of the method."""
         font_file = tempfile.NamedTemporaryFile()
-        font = make_font('')
+        font = make_font("")
         font.save(font_file.name)
         charset = coverage.character_set(font_file.name)
 
-        self.assertTrue(ord(' ') in charset)
-        self.assertTrue(ord('A') in charset)
+        self.assertTrue(ord(" ") in charset)
+        self.assertTrue(ord("A") in charset)
         self.assertFalse(0x10B00 in charset)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
